gg_tsresiduals: Ensemble of time series residual diagnostic plots
Description
Usage
gg_tsresiduals(data, type = "innovation", plot_type = "histogram", ...)
Value
A list of ggplot objects showing a useful plots of a time series model's residuals.
Arguments
data
A mable containing one model with residuals.
type
The type of residuals to compute. If type="response", residuals on the back-transformed data will be computed.
plot_type
type of plot to include in lower right corner. By default
("auto") a season plot will be shown for seasonal data, a spectrum plot
will be shown for non-seasonal data without missing values, and a PACF will
be shown otherwise.
...
Additional arguments passed to gg_tsdisplay().
Details
gg_tsresiduals() was soft deprecated in feasts 0.4.2. Please use ggtime::gg_tsresiduals() instead.
Plots the residuals using a time series plot, ACF and histogram.
References
Hyndman and Athanasopoulos (2019) Forecasting: principles
and practice, 3rd edition, OTexts: Melbourne, Australia.
https://OTexts.com/fpp3/