cointegration_phillips_ouliaris: Phillips and Ouliaris Cointegration Test
Description
Performs the Phillips and Ouliaris "Pu" and "Pz"
cointegration test.
Usage
cointegration_phillips_ouliaris(x, ...)
Value
An object of class ca.po.
Arguments
x
Matrix of data to be tested.
...
Additional arguments passed to urca::ca.po().
Author
Bernhard Pfaff
Details
The test "Pz", compared to the test "Pu", has the
advantage that it is invariant to the normalization of the
cointegration vector, i.e. it does not matter which variable
is on the left hand side of the equation. In case convergence
problems are encountered by matrix inversion, one can pass a higher
tolerance level via"tol=..." to the solve()-function.
References
Phillips, P.C.B. and Ouliaris, S. (1990), Asymptotic Properties of
Residual Based Tests for Cointegration, Econometrica,
Vol. 58, No. 1, 165--193.